@@ -1,7 +1,6 @@
 package HTTP::Tiny::NoProxy;
 our $AUTHORITY = 'cpan:SUKRIA';
-$HTTP::Tiny::NoProxy::VERSION = '1.3514_04'; # TRIAL
-$HTTP::Tiny::NoProxy::VERSION = '1.351404';
+$HTTP::Tiny::NoProxy::VERSION = '1.3500';
 use base 'HTTP::Tiny';
 
 # Simple subclass of HTTP::Tiny, adding the no_proxy argument, because we're
@@ -15,7 +14,7 @@ use base 'HTTP::Tiny';
 sub new {
     my ($self, %args) = @_;
 
-    $args{no_proxy} = [127.0.0.1, 127.0.0.11];
+    $args{no_proxy} = "127.0.0.1";
 
     return $self->SUPER::new(%args);
 }
@@ -35,7 +34,7 @@ HTTP::Tiny::NoProxy
 
 =head1 VERSION
 
-version 1.3514_04
+version 1.3500
 
 =head1 AUTHOR
 
