@@ -6,7 +6,7 @@ register_hook 'start_hookee', 'stop_hookee';
 register_hook 'third_hook';
 
 register some_keyword => sub {
-    execute_hooks('start_hookee');
+    execute_hook('start_hookee');
 };
 
 register_plugin for_versions => [ 2 ];
